@@ -493,6 +493,23 @@ class Dataset():
 
         return dataset_document
 
+    def set_data_last_update(self):
+
+        now = datetime.now()
+        body = {
+            "dataLastUpdate": now.strftime("%Y-%m-%dT%H:%M:%S")
+        }
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+
+        authentication_url2 = self._base_url_askdata + '/smartdataset/datasets/' + self._dataset_id + '/dataLastUpdate'
+        r = s.put(url=authentication_url2, headers=self._headers, json=body)
+
+
     def _get_settings(self) -> dict:
         """
         return setting's dataset, this method is valid only object dataset instantiated with slug
@@ -534,9 +551,9 @@ class Dataset():
         if int(n_entity) > len(entities_dataset["data"]):
             raise NameError('not all entities are fetching')
 
-
         return entities_dataset
 
+
     def copy_entity_dataset(self, entity_code: str, dataset_id_dest: str, settigs_entity_source: dict, dataset_type: str):
 
         if settigs_entity_source["custom"] == True:
